% % % % % % % % % % % % % % % % % % % % % % % % %
% % %     
% % % 2008-08-07: Adaptación de RCC5 
% % %
% % % 2008-06-05: Modificación de los overlapped 
% % %             y repaso de los demas.
% % %     
% % %     
% % % % % % % % % % % % % % % % % % % % % % % % % 

:- use_module(library(bounds)).

%******************************************%
%***                                    ***%
%***  RELACIONES RCC5 ENTRE REGIONES    ***%
%***                                    ***%
%******************************************%

%-------------------------------------
%  1. DR -> Desconectadas
%-------------------------------------
dr((X1a,Y1a,X2a,Y2a),(X1b,Y1b,X2b,Y2b)) :- 
    ( 
      X1a #> X2b;
      Y1a #> Y2b;
      X2a #< X1b;
      Y2a #< Y1b
    ).

%-------------------------------------
%  2. EQ  -> Igualdad
%-------------------------------------
eq((X1a,Y1a,X2a,Y2a),(X1b,Y1b,X2b,Y2b)) :- 
     X1a #= X1b,
     Y1a #= Y1b,
     X2a #= X2b,
     Y2a #= Y2b.

%-------------------------------------
%  3. PP  -> Parte Propia 
%-------------------------------------
pp((X1a,Y1a,X2a,Y2a),(X1b,Y1b,X2b,Y2b)) :-
       X1b #< X1a, X2b #> X2a, 
       Y1b #< Y1a, Y2b #> Y2a.

%-------------------------------------
%  4. PPi  -> Parte Propia Inversa
%-------------------------------------
ppi((X1a,Y1a,X2a,Y2a),(X1b,Y1b,X2b,Y2b)) :-
    pp((X1b,Y1b,X2b,Y2b),(X1a,Y1a,X2a,Y2a)).

%-------------------------------------
%  8. PO  -> Solapamiento
%-------------------------------------
po( (X1a,Y1a,X2a,Y2a) ,(X1b,Y1b,X2b,Y2b) ) :-
       in_p((X1a,Y1a,X2a,Y2a) ,(X1b,Y1b)),
       out_p((X1a,Y1a,X2a,Y2a) ,(X2b,Y2b)).
po( (X1a,Y1a,X2a,Y2a) ,(X1b,Y1b,X2b,Y2b) ) :-
       in_p((X1a,Y1a,X2a,Y2a) ,(X2b,Y2b)),
       out_p((X1a,Y1a,X2a,Y2a) ,(X1b,Y1b)).
po( (X1a,Y1a,X2a,Y2a) ,(X1b,Y1b,X2b,Y2b) ) :-
       in_p((X1b,Y1b,X2b,Y2b) ,(X1a,Y1a)),
       out_p((X1b,Y1b,X2b,Y2b) ,(X2a,Y2a)).
po( (X1a,Y1a,X2a,Y2a) ,(X1b,Y1b,X2b,Y2b) ) :-
       in_p((X1b,Y1b,X2b,Y2b) ,(X1a,Y1a)),
       out_p((X1b,Y1b,X2b,Y2b) ,(X2a,Y2a)).



%*******************************************%
%***                                     ***%
%***     RELACIONES DE PUNTOS            ***%
%***                                     ***%
%*******************************************%

%-------------------------------------
%  1. in
%-------------------------------------
in_p((X1b,Y1b,X2b,Y2b),(X1a,Y1a)) :-
      X1b #< X1a, X1a #< X2b, 
      Y1b #< Y1a, Y1a #< Y2b. 
      

%-------------------------------------
%  2. out
%-------------------------------------
out_p((X1,Y1,X2,Y2),(Xp,Yp)) :-
   (
      X1 #> Xp; Xp #> X2; 
      Y1 #> Yp; Yp #> Y2
   ). 
      

